/*
 * Copyright 2018 Equilinox Mod Kit Project
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *    the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package equilinoxmodkit.mod;


import java.lang.annotation.*;


/**
 * Annotation that declares vital information about an {@code EquilinoxMod}.<br>
 * This annotation should be present for all instances of an {@link EquilinoxMod} and cannot have an empty {@link #id()} parameter or mods will be
 * ignored by the Equilinox Mod Loader; {@link #version()} has to follow semantic versioning (e.g.: 0.4.3) and should not be empty for public releases
 * (an empty {@code version} parameter is accepted by the EML to make testing your mod easier).
 *
 * @author EMK Team
 */
@Target( ElementType.TYPE )
@Retention( RetentionPolicy.RUNTIME )
public @interface ModInfo {
	
	
	/**
	 * Unique identifier of a mod that is required for a mod to not be ignored by the Equilinox Mod Loader. The identifier should follow this
	 * format:<br>
	 * {@code author.name} in all lower case letters, {@code -} instead of spaces.
	 *
	 * @return Identifier of this mod.
	 */
	String id();
	
	/**
	 * Name of a mod that is displayed in the in-game mod browser (not yet implemented!).
	 *
	 * @return Name of this mod.
	 */
	String name();
	
	/**
	 * Version of a mod following the semantic version system for instance {@code 0.4.3} and should not be empty for public releases.
	 *
	 * @return Version of this mod.
	 */
	String version();
	
	/**
	 * Author of a mod.
	 *
	 * @return Author of this mod.
	 */
	String author();
	
	/**
	 * Optional description of what a mod does in a maximum of 100 characters.
	 *
	 * @return Description of this mod.
	 */
	String description();
	
	/**
	 * Optional path to a 64x64 thumbnail.
	 *
	 * @return Thumbnail of this mod.
	 */
	String thumbnail();
	
	
}
